@@ -33,7 +33,8 @@ class JediDatasetSpec(object):
         'nFilesFinished','nFilesFailed','nFilesOnHold',
         'nEvents','nEventsToBeUsed','nEventsUsed',
         'lockedBy','lockedTime','attributes','streamName',
-        'storageToken','destination','templateID','nFilesWaiting'
+        'storageToken','destination','templateID','nFilesWaiting',
+        'nFilesMissing'
         )
     # attributes which have 0 by default
     _zeroAttrs = ()
