@@ -178,7 +178,7 @@ class JediTaskBuffer(TaskBuffer.TaskBuffer, CommandReceiveInterface):
                                    fullSimulation=False,simDatasets=None,
                                    mergeUnThrottled=None,readMinFiles=False,
                                    numNewTaskWithJumbo=0, resource_name=None,
-                                   ignore_lock=False):
+                                   ignore_lock=False, target_tasks=None):
         with self.proxyPool.get() as proxy:
             return proxy.getTasksToBeProcessed_JEDI(pid,vo,workQueue,prodSourceLabel,cloudName,nTasks,nFiles,
                                                   simTasks=simTasks,
@@ -191,7 +191,8 @@ class JediTaskBuffer(TaskBuffer.TaskBuffer, CommandReceiveInterface):
                                                   readMinFiles=readMinFiles,
                                                   numNewTaskWithJumbo=numNewTaskWithJumbo,
                                                   resource_name=resource_name,
-                                                  ignore_lock=ignore_lock)
+                                                  ignore_lock=ignore_lock,
+                                                  target_tasks=target_tasks)
 
     # get tasks to be processed
     def checkWaitingTaskPrio_JEDI(self, vo, workQueue, prodSourceLabel, cloudName, resource_name=None):
@@ -222,11 +223,11 @@ class JediTaskBuffer(TaskBuffer.TaskBuffer, CommandReceiveInterface):
     # generate output files for task
     def getOutputFiles_JEDI(self,jediTaskID,provenanceID,simul,instantiateTmpl=False,instantiatedSite=None,
                             isUnMerging=False,isPrePro=False,xmlConfigJob=None,siteDsMap=None,middleName='',
-                            registerDatasets=False,parallelOutMap=None,fileIDPool=[]):
+                            registerDatasets=False,parallelOutMap=None,fileIDPool=[], n_files_per_chunk=1):
         with self.proxyPool.get() as proxy:
             return proxy.getOutputFiles_JEDI(jediTaskID,provenanceID,simul,instantiateTmpl,instantiatedSite,
                                            isUnMerging,isPrePro,xmlConfigJob,siteDsMap,middleName,
-                                           registerDatasets,parallelOutMap,fileIDPool)
+                                           registerDatasets,parallelOutMap,fileIDPool, n_files_per_chunk)
 
     # insert output file templates
     def insertOutputTemplate_JEDI(self,templates):
@@ -442,12 +443,6 @@ class JediTaskBuffer(TaskBuffer.TaskBuffer, CommandReceiveInterface):
         with self.proxyPool.get() as proxy:
             return proxy.getPreproLog_JEDI(jediTaskID,simul)
 
-    # get sites with best connections to source
-    def getBestNNetworkSites_JEDI(self,source,protocol,nSites,threshold,cutoff,maxWeight):
-        with self.proxyPool.get() as proxy:
-            return proxy.getBestNNetworkSites_JEDI(source,protocol,nSites,threshold,
-                                                 cutoff,maxWeight)
-
     # get jobsetID
     def getUserJobsetID_JEDI(self,userName):
         with self.proxyPool.get() as proxy:
