@@ -38,8 +38,6 @@ class AtlasAnalWatchDog(TypicalWatchDogBase):
             self.doForPriorityMassage()
             # redo stalled analysis jobs
             self.doForRedoStalledJobs()
-            # throttle WAN data access
-            #self.doForThrottleWAN()
         except Exception:
             errtype,errvalue = sys.exc_info()[:2]
             origTmpLog.error('failed with {0} {1}'.format(errtype,errvalue))
@@ -556,124 +554,3 @@ class AtlasAnalWatchDog(TypicalWatchDogBase):
             errtype, errvalue = sys.exc_info()[:2]
             tmpLog.error('failed to redo stalled jobs with {0} {1} {2}'.format(errtype, errvalue, traceback.format_exc()))
 
-
-    # throttle WAN data access
-    def doForThrottleWAN(self):
-        tmpLog = MsgWrapper(logger, ' #ATM #KV doForThrottleWAN label=user')
-        tmpLog.debug('start')
-        # lock
-        got_lock = self.taskBufferIF.lockProcess_JEDI(  vo=self.vo, prodSourceLabel=self.prodSourceLabel,
-                                                        cloud=None, workqueue_id=None, resource_name=None,
-                                                        component='AtlasAnalWatchDog.doForThrottleWAN',
-                                                        pid=self.pid, timeLimit=6)
-        if not got_lock:
-            tmpLog.debug('locked by another process. Skipped')
-            return
-        # throttle WAN data access
-        tmpLog.debug('throttle WAN data access')
-        try:
-            # max number of activated jobs with WAN access
-            maxActivated = 5
-            # get WAN data matrix
-            wanMX = self.taskBufferIF.getWanDataFlowMaxtrix()
-            throttleForSink     = {}
-            throttleForSource   = {}
-            totalFlowFromSource = {}
-            # loop over all sources to get total flows
-            tmpLog.debug(" >>> checking limits")
-            for sinkSite in wanMX:
-                sinkMap = wanMX[sinkSite]
-                totalFlowToSink = 0
-                # loop over all sinks
-                for sourceSite in sinkMap:
-                    sourceMap = sinkMap[sourceSite]
-                    # get total flows
-                    totalFlowToSink += sourceMap['flow']
-                    totalFlowFromSource.setdefault(sourceSite, 0)
-                    totalFlowFromSource[sourceSite] += sourceMap['flow']
-                # check limit for sink
-                tmpSiteSpec = siteMapper.getSite(sinkSite)
-                if siteMapper.checkSite(sinkSite) and tmpSiteSpec.wansinklimit*1024*1024*1024 > totalFlowToSink:
-                    throttleForSink[sinkSite] = False
-                    tmpLog.debug(" release Sink {0} : {1}bps (total) < {2}Gbps (limit)".format(sinkSite,totalFlowToSink,
-                                                            tmpSiteSpec.wansinklimit))
-                else:
-                    throttleForSink[sinkSite] = True
-                    tmpLog.debug(" throttle Sink {0} : {1}bps (total) > {2}Gbps (limit)".format(sinkSite,totalFlowToSink,
-                                                             tmpSiteSpec.wansinklimit))
-            # check limit for source
-            for sourceSite in totalFlowFromSource:
-                totalFlow = totalFlowFromSource[sourceSite]
-                tmpSiteSpec = siteMapper.getSite(sourceSite)
-                if siteMapper.checkSite(sourceSite) and tmpSiteSpec.wansourcelimit*1024*1024*1024 > totalFlow:
-                    throttleForSource[sourceSite] = False
-                    tmpLog.debug(" release Src {0} : {1}bps (total) < {2}Gbps (limit)".format(sourceSite,totalFlow,
-                                                                                              tmpSiteSpec.wansourcelimit))
-                else:
-                    throttleForSource[sourceSite] = True
-                    tmpLog.debug(" throttle Src {0} : {1}bps (total) > {2}Gbps (limit)".format(sourceSite,totalFlow,
-                                                            tmpSiteSpec.wansourcelimit))
-            # loop over all sources to adjust flows
-            tmpLog.debug(" >>> adjusting flows")
-            for sinkSite in wanMX:
-                sinkMap = wanMX[sinkSite]
-                if throttleForSink[sinkSite]:
-                    # sink is throttled
-                    iJobs = 0
-                    for sourceSite in sinkMap:
-                        sourceMap = sinkMap[sourceSite]
-                        for prodUserName in sourceMap['user']:
-                            userMap = sourceMap['user'][prodUserName]
-                            for currentPriority in userMap['activated']['jobList']:
-                                jobList = userMap['activated']['jobList'][currentPriority]
-                                for pandaID in jobList:
-                                    tmpStat = self.taskBufferIF.throttleJob(pandaID)
-                                    if tmpStat == 1:
-                                        iJobs += 1
-                    tmpLog.debug(" throttled {0} jobs to {1}".format(iJobs,sinkSite))
-                else:
-                    # no throttle on sink
-                    for sourceSite in sinkMap:
-                        sourceMap = sinkMap[sourceSite]
-                        # check if source is throttled
-                        if throttleForSource[sourceSite]:
-                            # throttled
-                            iJobs = 0
-                            for prodUserName in sourceMap['user']:
-                                userMap = sourceMap['user'][prodUserName]
-                                for currentPriority in userMap['activated']['jobList']:
-                                    jobList = userMap['activated']['jobList'][currentPriority]
-                                    for pandaID in jobList:
-                                        tmpStat = self.taskBufferIF.throttleJob(pandaID)
-                                        if tmpStat == 1:
-                                            iJobs += 1
-                            tmpLog.debug(" throttled {0} jobs from {1} to {2}".format(iJobs,sourceSite,sinkSite))
-                        else:
-                            # unthrottled
-                            iJobs = 0
-                            for prodUserName in sourceMap['user']:
-                                userMap = sourceMap['user'][prodUserName]
-                                if userMap['activated']['nJobs'] < maxActivated:
-                                    # activate jobs with higher priorities
-                                    currentPriorityList = list(userMap['throttled']['jobList'])
-                                    currentPriorityList.sort()
-                                    currentPriorityList.reverse()
-                                    nActivated = userMap['activated']['nJobs']
-                                    for currentPriority in currentPriorityList:
-                                        if nActivated > maxActivated:
-                                            break
-                                        panaIDs = userMap['throttled']['jobList'][currentPriority]
-                                        panaIDs.sort()
-                                        for pandaID in panaIDs:
-                                            tmpStat = self.taskBufferIF.unThrottleJob(pandaID)
-                                            if tmpStat == 1:
-                                                nActivated += 1
-                                                iJobs += 1
-                                            if nActivated > maxActivated:
-                                                break
-                            tmpLog.debug(" activated {0} jobs from {1} to {2}".format(iJobs,sourceSite,sinkSite))
-            # done
-            tmpLog.debug('done')
-        except Exception:
-            errtype,errvalue = sys.exc_info()[:2]
-            tmpLog.error("failed to throttle WAN data access with %s %s" % (errtype,errvalue))
