@@ -1,3 +1,4 @@
+import json
 import re
 import sys
 import uuid
@@ -67,6 +68,9 @@ class TaskRefinerBase (object):
 
     # extract common parameters
     def extractCommon(self,jediTaskID,taskParamMap,workQueueMapper,splitRule):
+        # remove irrelevant
+        if 'maxAttempt' in taskParamMap and not taskParamMap['maxAttempt']:
+            del taskParamMap['maxAttempt']
         # make task spec
         taskSpec = JediTaskSpec()
         taskSpec.jediTaskID = jediTaskID
@@ -76,6 +80,8 @@ class TaskRefinerBase (object):
         taskSpec.vo = taskParamMap['vo']
         taskSpec.prodSourceLabel = taskParamMap['prodSourceLabel']
         taskSpec.taskPriority = taskParamMap['taskPriority']
+        if taskSpec.taskPriority is None:
+            taskSpec.taskPriority = 0
         if 'currentPriority' in taskParamMap:
             taskSpec.currentPriority = taskParamMap['currentPriority']
         else:
@@ -130,6 +136,8 @@ class TaskRefinerBase (object):
             taskSpec.ramCount = 0
         if 'ramUnit' in taskParamMap:
             taskSpec.ramUnit = taskParamMap['ramUnit']
+        elif 'ramCountUnit' in taskParamMap:
+            taskSpec.ramUnit = taskParamMap['ramCountUnit']
         if 'baseRamCount' in taskParamMap:
             taskSpec.baseRamCount = taskParamMap['baseRamCount']
         else:
@@ -376,6 +384,10 @@ class TaskRefinerBase (object):
             self.setSplitRule(taskParamMap, 'maxCoreCount', JediTaskSpec.splitRuleToken['maxCoreCount'])
         if 'cloudAsVO' in taskParamMap:
             self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['cloudAsVO'])
+        if 'pushJob' in taskParamMap and taskParamMap['pushJob']:
+            self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['pushJob'])
+        if 'onSiteMerging' in  taskParamMap and taskParamMap['onSiteMerging']:
+            self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['onSiteMerging'])
         # work queue
         workQueue = None
         if 'workQueueName' in taskParamMap:
@@ -515,6 +527,7 @@ class TaskRefinerBase (object):
                 datasetSpec.nFilesFailed = 0
                 datasetSpec.nFilesOnHold = 0
                 datasetSpec.nFilesWaiting = 0
+                datasetSpec.nFilesMissing = 0
                 datasetSpec.nEvents = 0
                 datasetSpec.nEventsUsed = 0
                 datasetSpec.nEventsToBeUsed = 0
@@ -873,7 +886,7 @@ class TaskRefinerBase (object):
     # get parameters for event service merging
     def getParamsForEventServiceMerging(self,taskParamMap):
         # no event service
-        if not self.taskSpec.useEventService():
+        if not self.taskSpec.useEventService() and self.taskSpec.on_site_merging():
             return None
         # extract parameters
         transPath = 'UnDefined'
@@ -882,8 +895,14 @@ class TaskRefinerBase (object):
             if 'transPath' in taskParamMap['esmergeSpec']:
                 transPath = taskParamMap['esmergeSpec']['transPath']
             if 'jobParameters' in taskParamMap['esmergeSpec']:
-                jobParameters = taskParamMap['esmergeSpec']['jobParameters']
+                jobParameters = jobParameters['esmergeSpec']['jobParameters']
         # return
+        if self.taskSpec.on_site_merging():
+            data = {}
+            data['transPath'] = transPath
+            data['jobParameters'] = jobParameters
+            data['nEventsPerOutputFile'] = jobParameters['nEventsPerOutputFile']
+            return '<___PANDA_MERGE___>' + json.dumps(data)
         return '<PANDA_ESMERGE_TRF>'+transPath+'</PANDA_ESMERGE_TRF>'+'<PANDA_ESMERGE_JOBP>'+jobParameters+'</PANDA_ESMERGE_JOBP>'
 
 
